@@ -14,12 +14,7 @@
 #include <kio/transferjob.h>
 #ifndef KIOCORE_ONLY
 #include <KIO/ApplicationLauncherJob>
-#include <kio_version.h>
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
 #include <KIO/JobUiDelegateFactory>
-#else
-#include <KIO/JobUiDelegate>
-#endif
 #include <KIO/OpenUrlJob>
 #include <KIO/StatJob>
 #include <KIO/UDSEntry>
@@ -171,7 +166,7 @@ int main(int argc, char **argv)
     QApplication app(argc, argv);
 #endif
 
-    KLocalizedString::setApplicationDomain("kioclient");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("kioclient"));
 
     QString appName = QStringLiteral("kioclient");
     QString programName = i18n("KIO Client");
@@ -249,18 +244,13 @@ bool ClientApp::kde_open(const QString &url, const QString &mimeType, bool allow
     }
 
     auto *job = new KIO::OpenUrlJob(info.url, mimeType);
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
     job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, nullptr));
-#else
-    job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, nullptr));
-#endif
     job->setRunExecutables(allowExec);
     job->setFollowRedirections(false);
     bool job_had_error = false;
     QObject::connect(job, &KJob::result, this, [&](KJob *job) {
         if (job->error()) {
             job_had_error = true;
-            qWarning().noquote() << job->errorString();
         }
     });
     job->start();
@@ -343,10 +333,10 @@ bool ClientApp::doRemove(const QStringList &urls)
 
 bool ClientApp::doStat(const QStringList &urls)
 {
-    KIO::Job *job = KIO::statDetails(makeURL(urls.first()),
-                                     KIO::StatJob::SourceSide,
-                                     (KIO::StatBasic | KIO::StatUser | KIO::StatTime | KIO::StatInode | KIO::StatMimeType | KIO::StatAcl),
-                                     s_jobFlags);
+    KIO::Job *job = KIO::stat(makeURL(urls.first()),
+                              KIO::StatJob::SourceSide,
+                              (KIO::StatBasic | KIO::StatUser | KIO::StatTime | KIO::StatInode | KIO::StatMimeType | KIO::StatAcl),
+                              s_jobFlags);
     if (!s_interactive) {
         job->setUiDelegate(nullptr);
         job->setUiDelegateExtension(nullptr);
@@ -423,11 +413,7 @@ bool ClientApp::doIt(const QCommandLineParser &parser)
         return kde_open(parser.positionalArguments().at(1), argc == 3 ? parser.positionalArguments().constLast() : QString(), true);
     } else if (command == QLatin1String("appmenu")) {
         auto *job = new KIO::ApplicationLauncherJob();
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
         job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, nullptr));
-#else
-        job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, nullptr));
-#endif
         connect(job, &KJob::result, this, &ClientApp::slotResult);
         job->start();
 
@@ -606,3 +592,5 @@ ClientApp::ClientApp()
     : QObject()
 {
 }
+
+#include "moc_kioclient.cpp"
